Algorithms

Struct Algorithms 

pub struct Algorithms { /* private fields */ }
Store information about all FM algorithms, and which functions to call to render them.

Implementations

Source

impl Algorithms

pub fn new() -> Self

Creates and initializes a new algorithm manager

pub fn init(&mut self)

Initializes all algorithms by compiling their opcodes

pub fn render_call(&self, algorithm: usize, op: usize) -> &RenderCall

Returns the render call for a specific algorithm and operator

pub fn is_modulator(&self, algorithm: usize, op: usize) -> bool

Checks if an operator is a modulator (not a carrier)