pub struct Algorithms { /* private fields */ }Expand description
Store information about all FM algorithms, and which functions to call to render them.
Implementations
Sourceimpl Algorithms
impl Algorithms
Sourcepub fn render_call(&self, algorithm: usize, op: usize) -> &RenderCall
pub fn render_call(&self, algorithm: usize, op: usize) -> &RenderCall
Returns the render call for a specific algorithm and operator
Sourcepub fn is_modulator(&self, algorithm: usize, op: usize) -> bool
pub fn is_modulator(&self, algorithm: usize, op: usize) -> bool
Checks if an operator is a modulator (not a carrier)